MODULE infotrac_phy


! nqtot : total number of tracers and higher order of moment, water vapor and liquid included
  INTEGER, SAVE :: nqtot
!$OMP THREADPRIVATE(nqtot)

!CR: on ajoute le nombre de traceurs de l eau
  INTEGER, SAVE :: nqo
!$OMP THREADPRIVATE(nqo)

! nbtr : number of tracers not including higher order of moment or water vapor or liquid
!        number of tracers used in the physics
  INTEGER, SAVE :: nbtr
!$OMP THREADPRIVATE(nbtr)

! Name variables
  CHARACTER(len=20), ALLOCATABLE, DIMENSION(:), SAVE :: tname ! tracer short name for restart and diagnostics
!$OMP THREADPRIVATE(tname)

  CHARACTER(len=23), ALLOCATABLE, DIMENSION(:), SAVE :: ttext ! tracer long name for diagnostics
!$OMP THREADPRIVATE(ttext)
! niadv : vector keeping the coorspondance between all tracers(nqtot) treated in the 
!         dynamic part of the code and the tracers (nbtr+2) used in the physics part of the code. 
  INTEGER, ALLOCATABLE, DIMENSION(:), SAVE    :: niadv ! equivalent dyn / physique
!$OMP THREADPRIVATE(niadv)

! pbl_flg(it)=0  : boundary layer diffusion desactivaded for tracer number it 
  INTEGER, ALLOCATABLE, DIMENSION(:), SAVE  :: pbl_flg
!$OMP THREADPRIVATE(pbl_flg)

! conv_flg(it)=0 : convection desactivated for tracer number it 
  INTEGER, ALLOCATABLE, DIMENSION(:), SAVE  :: conv_flg
!$OMP THREADPRIVATE(conv_flg)

  CHARACTER(len=8),DIMENSION(:),ALLOCATABLE, SAVE :: solsym
!$OMP THREADPRIVATE(solsym)

  CHARACTER(len=4),SAVE :: type_trac
!$OMP THREADPRIVATE(type_trac)

CONTAINS

  SUBROUTINE init_infotrac_phy(nbtr_,tname_,ttext_,niadv_)
  IMPLICIT NONE
    INTEGER :: nbtr_
    CHARACTER(len=20), DIMENSION(:) :: tname_ ! tracer short name for restart and diagnostics
    CHARACTER(len=23), DIMENSION(:) :: ttext_ ! tracer long name for diagnostics
    INTEGER,  DIMENSION(:)          :: niadv_ ! equivalent dyn / physique
    
    nbtr=nbtr_
    ALLOCATE(tname(size(tname_)))
    ALLOCATE(ttext(size(ttext_)))
    ALLOCATE(niadv(size(niadv_)))
    tname(:) = tname_(:)
    ttext(:) = ttext_(:)
    niadv(:) = niadv_(:)
  
  END SUBROUTINE init_infotrac_phy
  
  
END MODULE infotrac_phy
